@@ -183,8 +183,11 @@ char *
 shorten_disk_name (const char *dev, gint len)
 {
     char *r, *lastchars, *firstchars;
-    //if (strncmp(dev, "UUID", 4)==0 && 
-    if (strlen(dev)>len) // len canot be set lower than 9
+    if (strncmp(dev, "LABEL=", 6)==0)
+    {
+      r = g_strdup(dev+6*sizeof(char));
+    }
+    else if (strlen(dev)>len) // len canot be set lower than 9
     {
         // we want at least 5 characters at the end so that trimmed UUIDs are still readable
         lastchars = (char *) (dev + strlen(dev) - 5);
@@ -363,6 +366,54 @@ out:
     }
 }
 
+/**
+ * Checks whether the pdisk is already inserted with a similar path with more 
+ * or less slashes.
+ * @param pdisks  Pointer to disks array
+ * @param pdisk   Pointer to new disk to lateron insert into pdisks
+ * @return true if device or mount point does already exist, false otherwise
+ */
+gboolean
+device_or_mountpoint_exists (GPtrArray * pdisks, t_disk * pdisk)
+{
+  gboolean returnValue = FALSE;
+  int i;
+  t_disk *disk;
+  int stringlength1, stringlength2, stringlength3, stringlength4;
+  
+  stringlength1 = strlen(pdisk->device);
+  stringlength3 = strlen(pdisk->mount_point);
+  
+  for (i=0; i < pdisks->len ; i++)
+  {
+    disk = (t_disk *) (g_ptr_array_index(pdisks,i));
+    stringlength2 = strlen(disk->device);
+    stringlength4 = strlen(disk->mount_point);
+    
+    if (stringlength1==stringlength2+1 && pdisk->device[stringlength1-1]=='/' && strncmp(pdisk->device, disk->device, stringlength2)==0 )      
+    {
+      returnValue = TRUE;
+      break;
+    } 
+    else if (stringlength2==stringlength1+1 && disk->device[stringlength2-1]=='/' && strncmp(pdisk->device, disk->device, stringlength1)==0 )      
+    {
+      returnValue = TRUE;
+      break;
+    }
+    else if (stringlength3==stringlength4+1 && pdisk->mount_point[stringlength3-1]=='/' && strncmp(pdisk->mount_point, disk->mount_point, stringlength4)==0 )      
+    {
+      returnValue = TRUE;
+      break;
+    } 
+    else if (stringlength4==stringlength3+1 && disk->mount_point[stringlength4-1]=='/' && strncmp(pdisk->mount_point, disk->mount_point, stringlength3)==0 )      
+    {
+      returnValue = TRUE;
+      break;
+    }
+  }
+  
+  return returnValue;
+}
 
 /**
  * Fill a GPtrArray with pointers on struct t_disk containing infos on devices
@@ -389,7 +440,7 @@ disks_new (gboolean include_NFSs, gboolean *showed_fstab_dialog, gint length)
         if (! (*showed_fstab_dialog) ) {
             dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                                 GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-    "Your /etc/fstab could not be read. This will severely degrade the plugin's abilities.");
+    _("Your /etc/fstab could not be read. This will severely degrade the plugin's abilities."));
             /* gtk_dialog_run (GTK_DIALOG (dialog)); */
             g_signal_connect (dialog, "response",
                     G_CALLBACK (gtk_widget_destroy), dialog);
@@ -404,7 +455,7 @@ disks_new (gboolean include_NFSs, gboolean *showed_fstab_dialog, gint length)
     for (pfstab = getfsent(); pfstab!=NULL; pfstab = getfsent())
     {
         has_valid_mount_device =
-                        g_str_has_prefix(pfstab->fs_spec, "/dev/") ||  g_str_has_prefix(pfstab->fs_spec, "UUID=");
+                        g_str_has_prefix(pfstab->fs_spec, "/dev/") ||  g_str_has_prefix(pfstab->fs_spec, "UUID=") ||  g_str_has_prefix(pfstab->fs_spec, "LABEL=");
 
         if (include_NFSs)
             has_valid_mount_device = has_valid_mount_device |
@@ -418,7 +469,8 @@ disks_new (gboolean include_NFSs, gboolean *showed_fstab_dialog, gint length)
                 g_str_has_prefix(pfstab->fs_file, "/") ) {
             pdisk = disk_new (pfstab->fs_spec, pfstab->fs_file, length);
             pdisk->dc = disk_classify (pfstab->fs_spec, pfstab->fs_file);
-            g_ptr_array_add (pdisks , pdisk);
+            if (!device_or_mountpoint_exists(pdisks, pdisk))
+              g_ptr_array_add (pdisks , pdisk);
 
         }
 
@@ -477,18 +529,34 @@ disks_remove_device (GPtrArray * pdisks, char *device)
 {
     unsigned int i;
     gpointer p=NULL;
+    gboolean removedEntries = FALSE;
+    char *exclude_device;
+    size_t device_len;
 
     for (i=0; i < pdisks->len ; i++)
     {
-        if ( strcmp ( ((t_disk *) g_ptr_array_index(pdisks, i))->device,
+        exclude_device = ((t_disk *) g_ptr_array_index(pdisks, i))->device;
+        if ( strcmp ( exclude_device,
             device )==0 )
+        {
             p = g_ptr_array_remove_index(pdisks, i);
+              if (p!=NULL)
+                removedEntries = TRUE;
+        }
+        
+        device_len = strlen(device);
+        
+        if ( device[device_len-1]=='*' && 
+        strncmp ( exclude_device,
+            device, device_len-1 )==0 )
+        {
+            p = g_ptr_array_remove_index(pdisks, i);
+              if (p!=NULL)
+                removedEntries = TRUE;
+        }
     }
 
-    if (p==NULL)
-        return FALSE;
-    else
-        return TRUE;
+    return removedEntries;
 }
 
 
@@ -499,20 +567,39 @@ disks_remove_device (GPtrArray * pdisks, char *device)
 gboolean
 disks_remove_mountpoint (GPtrArray * pdisks, char *mountp)
 {
+    gboolean removedEntries = FALSE;
     unsigned int i;
     gpointer p=NULL;
+    char *exclude_mp;
+    size_t mountp_len;
 
     for (i=0; i < pdisks->len ; i++)
     {
-        if (strcmp ( ((t_disk *) g_ptr_array_index(pdisks, i))->mount_point,
+        exclude_mp = ((t_disk *) g_ptr_array_index(pdisks, i))->mount_point;
+      
+        if (strcmp ( exclude_mp,
             mountp)==0)
+        {
+          DBG("REMOVED %s @ %i %s", mountp, i, exclude_mp);
             p = g_ptr_array_remove_index(pdisks, i);
+            if (p!=NULL)
+                removedEntries = TRUE;
+        }
+        
+        mountp_len = strlen(mountp);
+        
+        if ( mountp[mountp_len-1]=='*' && 
+        strncmp ( exclude_mp,
+            mountp, mountp_len-1 )==0 )
+        {
+          DBG("removed %s @ %i %s", mountp, i, exclude_mp);
+            p = g_ptr_array_remove_index(pdisks, i);
+            if (p!=NULL)
+                removedEntries = TRUE;
+        }
     }
 
-    if (p==NULL)
-        return FALSE;
-    else
-        return TRUE;
+    return removedEntries;
 }
 
 
@@ -556,12 +643,14 @@ disks_free_mount_info(GPtrArray * pdisks)
 
 
 /**
- * Searches array for device and mounpoint. Returns TRUE if found.
+ * Searches array for device and mountpoint. Returns TRUE if found.
  */
 gboolean
 exclude_filesystem (GPtrArray *excluded_FSs, gchar *mountpoint, gchar *device)
 {
     unsigned int i;
+    gchar *excluded_FS_i; 
+    size_t excluded_FS_i_len = 0;
 
     TRACE("Entering exclude_filesystems");
 
@@ -569,14 +658,26 @@ exclude_filesystem (GPtrArray *excluded_FSs, gchar *mountpoint, gchar *device)
 
     for (i=0; i < excluded_FSs->len; i++)
     {
-        DBG("Comparing %s and %s to %s", mountpoint, device, (gchar *) g_ptr_array_index(excluded_FSs, i));
+        excluded_FS_i = (gchar *) g_ptr_array_index(excluded_FSs, i);
+        DBG("Comparing %s and %s to %s", mountpoint, device, excluded_FS_i);
         if (g_ascii_strcasecmp (
-                (gchar *) g_ptr_array_index(excluded_FSs, i), mountpoint)==0
+                excluded_FS_i, mountpoint)==0
             ||
             g_ascii_strcasecmp (
-                (gchar *) g_ptr_array_index(excluded_FSs, i), device)==0
+                excluded_FS_i, device)==0
             )
             return TRUE;
+            
+        excluded_FS_i_len = strlen(excluded_FS_i);
+        
+        if ((excluded_FS_i[excluded_FS_i_len-1]=='*') && 
+            (g_ascii_strncasecmp (
+                excluded_FS_i, mountpoint, excluded_FS_i_len-1)==0
+            ||
+            g_ascii_strncasecmp (
+                excluded_FS_i, device, excluded_FS_i_len-1)==0
+            ))
+            return TRUE;
     }
 
     TRACE("Leaving exclude_filesystems with FALSE");
@@ -723,7 +824,7 @@ disk_classify (char *device, char *mountpoint)
             dc = REMOTE;
         }
     }
-		/* it needs to be said _here_ that BSDs use cd0, cd1 etc., so we hope cd* works for cdrw, cdrom and cd0,1,... nd no other devices */
+    /* it needs to be said _here_ that BSDs use cd0, cd1 etc., so we hope cd* works for cdrw, cdrom and cd0,1,... nd no other devices */
     else if ( strstr(device, "cd") 
                 || strstr(device, "dvd") || strstr(mountpoint, "cd") || strstr(mountpoint, "dvd")) {
         dc = CD_DVD;
