@@ -168,7 +168,7 @@ disk_display_new (t_disk *disk, t_mounter *mounter)
         if (mounter->exclude_devicenames)
             dd->label_disk = gtk_label_new (disk->mount_point);
         else
-            dd->label_disk = gtk_label_new (g_strconcat(formatted_diskname, " -> ",
+            dd->label_disk = gtk_label_new (g_strconcat(formatted_diskname, _(" -> "),
                                         disk->mount_point, NULL));
 
         g_free (formatted_diskname);
@@ -220,7 +220,7 @@ disk_display_refresh (t_disk_display * disk_display)
             used = get_size_human_readable (mount_info->used);
             size = get_size_human_readable (mount_info->size);
             avail = get_size_human_readable (mount_info->avail);
-            text = g_strdup_printf ("[%s/%s] %s free", used, size, avail);
+            text = g_strdup_printf (_("[%s/%s] %s free"), used, size, avail);
 
             g_free(used);
             g_free(size);
@@ -351,8 +351,9 @@ on_button_press (GtkWidget *widget, GdkEventButton *event, t_mounter *mounter)
     {
 
         mounter_refresh (mounter); /* refreshs infos regarding mounts data */
-        gtk_menu_popup (GTK_MENU(mounter->menu), NULL, NULL, NULL, NULL, 0,
-                        event->time);
+        gtk_menu_popup (GTK_MENU(mounter->menu), NULL, NULL,
+                        xfce_panel_plugin_position_menu, mounter->plugin,
+                        0, event->time);
         return TRUE;
     }
     TRACE ("leaves on_button_press");
@@ -995,7 +996,9 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
     gtk_tooltips_set_tip ( GTK_TOOLTIPS(tip), _eventbox,
         _("Exclude the following file systems from the menu.\n"
         "The list is separated by simple spaces.\n"
-        "It is up to you to specify correct devices or mount points."),
+        "It is up to you to specify correct devices or mount points.\n"
+        "An asterisk (*) can be used as a placeholder at the end of\n"
+        "a path, e.g., \"/mnt/*\" to exclude any mountpoints below \"/mnt\".\n"),
         NULL );
 
     _vbox2 = gtk_vbox_new (FALSE, BORDER);
